aboutsummaryrefslogtreecommitdiffhomepage
path: root/tensorflow/core/distributed_runtime/rpc/grpc_server_lib.h
diff options
context:
space:
mode:
Diffstat (limited to 'tensorflow/core/distributed_runtime/rpc/grpc_server_lib.h')
-rw-r--r--tensorflow/core/distributed_runtime/rpc/grpc_server_lib.h15
1 files changed, 6 insertions, 9 deletions
diff --git a/tensorflow/core/distributed_runtime/rpc/grpc_server_lib.h b/tensorflow/core/distributed_runtime/rpc/grpc_server_lib.h
index 3b66291a9a..7b54bb84c8 100644
--- a/tensorflow/core/distributed_runtime/rpc/grpc_server_lib.h
+++ b/tensorflow/core/distributed_runtime/rpc/grpc_server_lib.h
@@ -37,9 +37,7 @@ class GrpcWorker;
class Master;
// function that creates a RendezvousMgr.
-typedef std::function<RendezvousMgrInterface*(
- const WorkerEnv*, const std::string& worker_name,
- WorkerCacheInterface* worker_cache)>
+typedef std::function<RendezvousMgrInterface*(const WorkerEnv*)>
RendezvousMgrCreationFunction;
// function that registers a service to the server. The service needs to
@@ -67,7 +65,7 @@ class GrpcServer : public ServerInterface {
protected:
Status Init(ServiceInitFunction service_func,
- RendezvousMgrCreationFunction rendezvous_mgr_func);
+ const RendezvousMgrCreationFunction& rendezvous_mgr_func);
Status Init();
@@ -75,17 +73,16 @@ class GrpcServer : public ServerInterface {
virtual std::shared_ptr<::grpc::ServerCredentials> GetServerCredentials(
const ServerDef& server_def) const;
- virtual ChannelCreationFunction GetChannelCreationFunction(
- const ServerDef& server_def) const;
+ virtual ChannelCreationFunction GetChannelCreationFunction() const;
virtual std::unique_ptr<Master> CreateMaster(MasterEnv* master_env);
// Creates a WorkerCacheInterface for a session.
- Status WorkerCacheFactory(const ServerDef& server_def,
+ Status WorkerCacheFactory(const WorkerCacheFactoryOptions& options,
WorkerCacheInterface** worker_cache);
- // Parses a ServerDef into a GrpcChannelSpec.
- Status ParseChannelSpec(const ServerDef& server_def,
+ // Parses a WorkerCacheFactoryOptions into a GrpcChannelSpec.
+ Status ParseChannelSpec(const WorkerCacheFactoryOptions& options,
GrpcChannelSpec* channel_spec);
// Returns the port to which this server is bound.